@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE DeriveDataTypeable #-}
 {-# LANGUAGE FlexibleContexts #-}
 {-# LANGUAGE TemplateHaskell #-}
@@ -37,7 +38,10 @@ instance Monad Result where
     return = Ok
     Error s >>= _ = Error s
     Ok v >>= f = f v
+#if MIN_VERSION_base(4,13,0)
+instance MonadFail Result where
     fail = Error
+#endif
 instance Functor Result where
     fmap = liftM
 instance Applicative Result where
