@@ -360,7 +360,10 @@ contentsToShakespeare rs a = do
             up <- [|\r' (u, p) -> r' u p|]
             return $ wrap rs `AppE` (ts `AppE` (up `AppE` VarE r `AppE` derefToExp [] d))
         contentToBuilder r (ContentMix d) =
-            return $ derefToExp [] d `AppE` VarE r
+            return $
+              if justVarInterpolation rs
+                then derefToExp [] d
+                else derefToExp [] d `AppE` VarE r
 
 shakespeare :: ShakespeareSettings -> QuasiQuoter
 shakespeare r = QuasiQuoter { quoteExp = shakespeareFromString r }
@@ -426,7 +429,11 @@ shakespeareFileReload settings fp = do
     vtToExp (d, vt) = do
         d' <- lift d
         c' <- c vt
-        return $ TupE [d', c' `AppE` derefToExp [] d]
+        return $ TupE
+#if MIN_VERSION_template_haskell(2,16,0)
+          $ map Just
+#endif
+          [d', c' `AppE` derefToExp [] d]
       where
         c :: VarType -> Q Exp
         c VTPlain = [|EPlain . $(return $
